Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(120)

Unified Diff: src/compiler/js-operator.h

Issue 1205473004: [turbofan] Make global variable loads and stores explicit. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/js-generic-lowering.cc ('k') | src/compiler/js-operator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/js-operator.h
diff --git a/src/compiler/js-operator.h b/src/compiler/js-operator.h
index 222383f0eced94d69eb71b0772e1bca93b9e93e6..a0f2668a14325c7991d4459c8adb8a1c5ad01216 100644
--- a/src/compiler/js-operator.h
+++ b/src/compiler/js-operator.h
@@ -227,7 +227,7 @@ DynamicContextAccess const& DynamicContextAccessOf(Operator const*);
// Defines the property being loaded from an object by a named load. This is
// used as a parameter by JSLoadNamed operators.
class LoadNamedParameters final {
public:
LoadNamedParameters(const Unique<Name>& name, const VectorSlotPair& feedback,
@@ -254,6 +254,8 @@ std::ostream& operator<<(std::ostream&, LoadNamedParameters const&);
const LoadNamedParameters& LoadNamedParametersOf(const Operator* op);
+const LoadNamedParameters& LoadGlobalParametersOf(const Operator* op);
+
// Defines the property being loaded from an object. This is
// used as a parameter by JSLoadProperty operators.
@@ -279,7 +281,7 @@ const LoadPropertyParameters& LoadPropertyParametersOf(const Operator* op);
// Defines the property being stored to an object by a named store. This is
// used as a parameter by JSStoreNamed operators.
class StoreNamedParameters final {
public:
StoreNamedParameters(LanguageMode language_mode,
@@ -305,6 +307,8 @@ std::ostream& operator<<(std::ostream&, StoreNamedParameters const&);
const StoreNamedParameters& StoreNamedParametersOf(const Operator* op);
+const StoreNamedParameters& StoreGlobalParametersOf(const Operator* op);
+
// Defines the property being stored to an object. This is used as a parameter
// by JSStoreProperty operators.
@@ -408,8 +412,7 @@ class JSOperatorBuilder final : public ZoneObject {
const Operator* LoadProperty(const VectorSlotPair& feedback);
const Operator* LoadNamed(const Unique<Name>& name,
- const VectorSlotPair& feedback,
- ContextualMode contextual_mode = NOT_CONTEXTUAL);
+ const VectorSlotPair& feedback);
const Operator* StoreProperty(LanguageMode language_mode,
const VectorSlotPair& feedback);
@@ -421,6 +424,13 @@ class JSOperatorBuilder final : public ZoneObject {
const Operator* HasProperty();
+ const Operator* LoadGlobal(const Unique<Name>& name,
+ const VectorSlotPair& feedback,
+ ContextualMode contextual_mode = NOT_CONTEXTUAL);
+ const Operator* StoreGlobal(LanguageMode language_mode,
+ const Unique<Name>& name,
+ const VectorSlotPair& feedback);
+
const Operator* LoadContext(size_t depth, size_t index, bool immutable);
const Operator* StoreContext(size_t depth, size_t index);
« no previous file with comments | « src/compiler/js-generic-lowering.cc ('k') | src/compiler/js-operator.cc » ('j') | no next file with comments »
@@ -227,7 +227,7 @@ DynamicContextAccess const& DynamicContextAccessOf(Operator const*);
// Defines the property being loaded from an object by a named load. This is
-// used as a parameter by JSLoadNamed operators.
+// used as a parameter by JSLoadNamed and JSLoadGlobal operators.
class LoadNamedParameters final {
public:
@@ -279,7 +281,7 @@ const LoadPropertyParameters& LoadPropertyParametersOf(const Operator* op);
// Defines the property being stored to an object by a named store. This is
-// used as a parameter by JSStoreNamed operators.
+// used as a parameter by JSStoreNamed and JSStoreGlobal operators.
class StoreNamedParameters final {
public:

Powered by Google App Engine
This is Rietveld 408576698